ELoadPurchaseController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • ELoadPurchaseController
Implemented types

Constructors

ELoadPurchaseController()

Properties

balanceAftertopUpKHR ↔ RxString
getter/setter pair
balanceAfterTopupUSD ↔ RxString
getter/setter pair
cartId ↔ RxString
Cart details
getter/setter pair
clockTimer ↔ Rx<Duration>
getter/setter pair
commission ↔ RxString
getter/setter pair
currency ↔ RxString
getter/setter pair
detailsList ↔ RxList<DetailSuccess>
getter/setter pair
docUrl ↔ RxString
getter/setter pair
eloadList ↔ RxList<StockOrderHistoryList>
getter/setter pair
eLoadTnxId ↔ RxString
getter/setter pair
fromDateController → Rx<TextEditingController>
final
grandTotal ↔ RxString
getter/setter pair
grandTotalInLocalCurrency ↔ RxString
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDateSelected ↔ RxBool
getter/setter pair
isLoadingGetCartApi ↔ RxBool
getter/setter pair
isResend ↔ RxBool
getter/setter pair
isSuccessCartAPI ↔ RxBool
getter/setter pair
listeners int
no setterinherited
localCurrency ↔ RxString
getter/setter pair
netCommission ↔ RxString
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
packageName ↔ RxBool
getter/setter pair
rechargeAmount ↔ RxString
getter/setter pair
resendSec int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondsRemaining ↔ RxInt
getter/setter pair
secondsRemainingStore ↔ RxInt
getter/setter pair
sellingPrice ↔ RxString
getter/setter pair
sellingUnitPrice ↔ RxString
getter/setter pair
storage → GetStorage
final
summaryList ↔ RxList<DetailSuccess>
getter/setter pair
timer Timer?
getter/setter pair
timerStore Timer?
getter/setter pair
timeStamp ↔ RxDouble
getter/setter pair
toDateController → Rx<TextEditingController>
final
totalList int
getter/setter pair
transactionsReceived ↔ RxBool
Transaction History
getter/setter pair
txnDate ↔ RxString
getter/setter pair
wht ↔ RxString
getter/setter pair
whtPercentage ↔ RxDouble
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
buildGraphQLInlineObject(List<CollectPaymentModeList>? value) String
callCartDetailsApi({required int enteredAmount, required int eLoadMinAmount, required int eLoadMaxAmount, required String offerId, required String amount, required String pogId, required String receiverMsisdn}) Future<void>
callELoadTransactionForGraphQl(String? pogId, String? offerId, String? amount, String? receiverMsisdn, String? paymentTransactionId) Future<void>
callTransactionHistoryApi(int offset, int limit, String fromDate, String toDate, {String? transactionSubType}) Future<void>
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getCart({required String cartId}) Future<void>
getCartIdAndHandlerApi(String? pogId, String? offerId, String? amount, String? receiverMsisdn) Future<void>
getELoadCartTransaction() Future<void>
getInvoice(String tnxId) Future<void>
getInvoiceOrReceiptForTransactionHistory(String transactionId, List<String> attachmentType) Future<void>
getReceipt(String transactionId) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
showProgressAndNavigate(String paymentStatus) Future<void>
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited