TopupController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • TopupController
Implemented types

Constructors

TopupController()

Properties

amountController TextEditingController
final
amountSelect ↔ RxBool
getter/setter pair
balance ↔ RxDouble
getter/setter pair
balanceAftertopUpKHR ↔ RxString
getter/setter pair
balanceAfterTopupUSD ↔ RxString
getter/setter pair
cart_id ↔ RxString
getter/setter pair
clockTimer ↔ Rx<Duration>
getter/setter pair
configDetailsList ↔ RxList<ConfigDetail>
getter/setter pair
dio → Dio
final
docUrl ↔ RxString
getter/setter pair
fullname ↔ RxString
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
iLoadSelectList ↔ RxList<Denomination>
getter/setter pair
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isBoxError ↔ RxBool
getter/setter pair
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isConvertLoading ↔ RxBool
getter/setter pair
isELoadOrderReceived ↔ RxBool
getter/setter pair
isError ↔ RxBool
getter/setter pair
isLoading ↔ RxBool
getter/setter pair
isLoadingAmountMore ↔ RxBool
getter/setter pair
isLoadingMore ↔ RxBool
getter/setter pair
isResend ↔ RxBool
getter/setter pair
isResponseReceived ↔ RxBool
getter/setter pair
isScratchLoading ↔ RxBool
getter/setter pair
isTopUpSuccess bool
getter/setter pair
levelId ↔ RxString
getter/setter pair
listeners int
no setterinherited
numberStatus ↔ RxString
getter/setter pair
offerID ↔ RxString
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
phoneNumberController TextEditingController
getter/setter pair
pinAttempt ↔ RxInt
getter/setter pair
pogID ↔ RxString
getter/setter pair
priceKHR ↔ RxString
getter/setter pair
rechargeAmount ↔ RxString
getter/setter pair
resendSec int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scratchcard ↔ RxString
getter/setter pair
scratchCardNumberController TextEditingController
final
scratchCardStatus ↔ RxString
getter/setter pair
secondsRemaining ↔ RxInt
getter/setter pair
secondsRemainingStore ↔ RxInt
getter/setter pair
storage → GetStorage
final
timer Timer?
getter/setter pair
timerStore Timer?
getter/setter pair
totalList int
getter/setter pair
transactionId ↔ RxString
getter/setter pair
txnDate ↔ RxString
getter/setter pair
userType ↔ RxString
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
callConvertCurrencyApi(String from, String to, String amount) Future<void>
calliLoadBalanceApi() Future<void>
callILoadPurchaseOrderApi() Future<void>
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
startStoreTimer(int sec) Future<void>
startTimer(int sec) Future<void>
stopStoreTimer() Future<void>
stopTimer() Future<void>
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited