Response class

Annotations
  • @JsonSerializable.new()

Constructors

Response({String? accountId, String? entityId, String? balance, String? walletTypeId, String? modifiedDate, String? expiryDate})
Response.fromJson(Map<String, dynamic> json)
factory

Properties

accountId String?
getter/setter pair
balance String?
getter/setter pair
entityId String?
getter/setter pair
expiryDate String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
modifiedDate String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walletTypeId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited