Content class

Annotations
  • @JsonSerializable.new()

Constructors

Content({String? transactionId, String? referenceId, String? partnerId, String? transactionType, double? amount, int? balanceBefore, int? balanceAfter, String? transactionTime, String? operatedBy, String? operateByUserName, String? orderId, String? remarks, String? accountId})
Content.fromJson(Map<String, dynamic> json)
factory

Properties

accountId String?
getter/setter pair
amount double?
getter/setter pair
balanceAfter int?
getter/setter pair
balanceBefore int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
operateByUserName String?
getter/setter pair
operatedBy String?
getter/setter pair
orderId String?
getter/setter pair
partnerId String?
getter/setter pair
referenceId String?
getter/setter pair
remarks String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String?
getter/setter pair
transactionTime String?
getter/setter pair
transactionType String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited