SecureStorageService class

Constructors

SecureStorageService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accessToken → const String
cashRegisterID → const String
designationId → const String
emailId → const String
fullName → const String
lastName → const String
levelIdLogin → const String
levelNameLogin → const String
mobileNo → const String
partnerIdLogin → const String
positionId → const String
preferedUserName → const String
refreshToken → const String
selectedStoreId → const String
userCategory → const String
userId → const String
xUserId → const String
xUserName → const String