SecureStorageInterface class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteSecureData(
String key) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readSecureData(
String key) → dynamic -
readSecureDataModel<
T> (String key, T fromJson(Map< String, dynamic> )) → T? -
toString(
) → String -
A string representation of this object.
inherited
-
writeSecureData(
String key, String value) → Future< void> -
writeSecureDataModel(
String key, dynamic model) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited