UserChecker class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isDealerUser(
) → bool -
isSAUser(
) → bool -
isStoreInventoryUser(
) → bool - Method for getting the tab privilage
-
isStoreUser(
) → bool -
userWithCashRegisterId(
) → bool - Method for designation privilage
-
userWithInventory(
) → bool - Method for inventory privilage
-
userWithMyStock(
) → bool - Method for my stock privilage